You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by rj...@apache.org on 2014/10/03 18:58:51 UTC

svn commit: r1629259 - in /httpd/httpd/branches/2.4.x: ./ modules/examples/mod_example_hooks.c

Author: rjung
Date: Fri Oct  3 16:58:50 2014
New Revision: 1629259

URL: http://svn.apache.org/r1629259
Log:
Backport of r1629235:
mod_example_hooks: Fix some comments and log messages: module was
renamed form mod_example to mod_example_hooks long ago.

Modified:
    httpd/httpd/branches/2.4.x/   (props changed)
    httpd/httpd/branches/2.4.x/modules/examples/mod_example_hooks.c

Propchange: httpd/httpd/branches/2.4.x/
------------------------------------------------------------------------------
  Merged /httpd/httpd/trunk:r1629235

Modified: httpd/httpd/branches/2.4.x/modules/examples/mod_example_hooks.c
URL: http://svn.apache.org/viewvc/httpd/httpd/branches/2.4.x/modules/examples/mod_example_hooks.c?rev=1629259&r1=1629258&r2=1629259&view=diff
==============================================================================
--- httpd/httpd/branches/2.4.x/modules/examples/mod_example_hooks.c (original)
+++ httpd/httpd/branches/2.4.x/modules/examples/mod_example_hooks.c Fri Oct  3 16:58:50 2014
@@ -15,7 +15,7 @@
  */
 
 /*
  * Apache example module.  Provide demonstrations of how modules do things.
  * It is not meant to be used in a production server.  Since it participates
  * in all of the processing phases, it could conceivable interfere with
  * the proper operation of other modules -- particularly the ones related
@@ -26,7 +26,7 @@
  * prefixed with 'x_' instead of 'example_'.
  *
  * To use mod_example_hooks, configure the Apache build with
  * --enable-example and compile.  Set up a <Location> block in your
  * configuration file like so:
  *
  * <Location /example>
@@ -328,11 +328,11 @@ static x_cfg *our_cconfig(const conn_rec
 static void example_log_each(apr_pool_t *p, server_rec *s, const char *note)
 {
     if (s != NULL) {
-        ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s, "mod_example: %s", note);
+        ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s, "mod_example_hooks: %s", note);
     } else {
         apr_file_t *out = NULL;
         apr_file_open_stderr(&out, p);
-        apr_file_printf(out, "mod_example traced in non-loggable "
+        apr_file_printf(out, "mod_example_hooks traced in non-loggable "
                         "context: %s\n", note);
     }
 }
@@ -703,7 +703,7 @@ static void *x_merge_server_config(apr_p
  * declaration near the bottom of this file.)  Note that these may be       *
  * called for situations that don't relate primarily to our function - in   *
  * other words, the fixup handler shouldn't assume that the request has     *
  * to do with "example" stuff.                                              *
  *                                                                          *
  * With the exception of the content handler, all of our routines will be   *
  * called for each request, unless an earlier handler from another module   *
@@ -15,7 +15,7 @@
 
 /*
- * Apache example module.  Provide demonstrations of how modules do things.
+ * Apache example_hooks module.  Provide demonstrations of how modules do things.
  * It is not meant to be used in a production server.  Since it participates
  * in all of the processing phases, it could conceivable interfere with
@@ -26,7 +26,7 @@
  *
  * To use mod_example_hooks, configure the Apache build with
- * --enable-example and compile.  Set up a <Location> block in your
+ * --enable-example-hooks and compile.  Set up a <Location> block in your
  * configuration file like so:
  *
@@ -703,7 +703,7 @@ static void *x_merge_server_config(apr_p
  * called for situations that don't relate primarily to our function - in   *
  * other words, the fixup handler shouldn't assume that the request has     *
- * to do with "example" stuff.                                              *
+ * to do with "example_hooks" stuff.                                        *
  *                                                                          *
  * With the exception of the content handler, all of our routines will be   *